==> ksetiwatch-2.0.2.tar.gz: ksetiwatch-2.0.2/ksetiwatch/options.h <==
/***************************************************************************
                          options.h  -  description
                             -------------------
    begin                : Tue Nov 23 1999
    copyright            : (C) 1999 by Gordon Machel
    email                : gmachel@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef OPTIONS_H
#define OPTIONS_H

#include <qwidget.h>
#include <qgroupbox.h>
#include <qbuttongroup.h>
#include <qslider.h>
#include <qcheckbox.h>
#include <qradiobutton.h>

/**
  *@author Gordon Machel
  */

class Options : public QWidget
{
Q_OBJECT

public:
	Options(QWidget *parent=0, const char *name=0);
	~Options();

protected slots:
	void handleTimeFormat(int id);
	void handleNotifyPeak(int id);
	void handlePanel();
  void handleGrid();
	void setRefreshInterval(int ri);
	
protected: 
	QGroupBox*    QGroupBox_1;
	QSlider*      QSlider_3;
	QCheckBox*    QCheckBox_1;
	QCheckBox*    Grid;
	QButtonGroup* TimeFormatGroup;
	QRadioButton* TimeFormat[2];
	QButtonGroup* NotifyPeakGroup;
	QCheckBox*    NotifyPeak[2];

signals:
  void dockStatusChanged();
};

#endif

==> ksetiwatch-2.2.0.tar.gz: ksetiwatch-2.2.0/ksetiwatch/options.h <==
/***************************************************************************
                          options.h  -  description
                             -------------------
    begin                : Tue Nov 23 1999
    copyright            : (C) 1999 by Gordon Machel
    email                : gmachel@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef OPTIONS_H
#define OPTIONS_H

#include <qwidget.h>

class QGroupBox;
class QButtonGroup;
class QSlider;
class QCheckBox;
class QRadioButton;

/**
  *@author Gordon Machel
  */

class Options : public QWidget
{
Q_OBJECT

public:
	Options(QWidget *parent=0, const char *name=0);
	~Options();

protected slots:
	void handleTimeFormat(int id);
	void handleNotifyPeak(int id);
	void handlePanel();
  void handleGrid();
	void setRefreshInterval(int ri);
	
protected: 
	QGroupBox*    QGroupBox_1;
	QSlider*      QSlider_3;
	QCheckBox*    QCheckBox_1;
	QCheckBox*    Grid;
	QButtonGroup* TimeFormatGroup;
	QRadioButton* TimeFormat[2];
	QButtonGroup* NotifyPeakGroup;
	QCheckBox*    NotifyPeak[2];

signals:
  void dockStatusChanged();
};

#endif
